<?php

namespace Drupal\commerce_vado\Resolver;

use Drupal\commerce\Context;
use Drupal\commerce\PurchasableEntityInterface;
use Drupal\commerce_price\Resolver\PriceResolverInterface;
use Drupal\commerce_product\Entity\ProductVariationInterface;
use Drupal\commerce_store\CurrentStoreInterface;
use Drupal\commerce_price\Price;

class VadoPriceResolver implements PriceResolverInterface {
  
  /**
   * The current store.
   *
   * @var \Drupal\commerce_store\CurrentStoreInterface
   */
  protected $currentStore;

  /**
   * {@inheritdoc}
   */
  public function resolve(PurchasableEntityInterface $entity, $quantity, Context $context) {
    if (!$entity->hasField('field_variation_addon')) {
      return NULL;
    }
    $discount_multiplier = 1;
    if ($entity->hasField('field_variation_addon_multiplier') && !$entity->get('field_variation_addon_multiplier')->isEmpty()) {
      $discount_multiplier = $entity->get('field_variation_addon_multiplier')->value;
    }
    $price = $entity->getPrice();
    /** @var \Drupal\commerce\PurchasableEntityInterface $addon_variation */
    foreach ($entity->get('field_variation_addon')->referencedEntities() as $addon_variation) {
      $addon_price = $addon_variation->getPrice()->multiply($discount_multiplier);
      $price = $price->add($addon_price);
    }
    return $price;
  }
}
